useSymbolzeit | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

- unified-mandala
- unifiedmandala-ui/hooks/useSymbolzeit
- useSymbolzeit

# Function useSymbolzeit

- useSymbolzeit(): {
  farbe: string;
  phase: string;
  }

- #### Returns {
  farbe: string;
  phase: string;
  }

  - ##### farbe: string

  - ##### phase: string

  - Defined in packages/unifiedmandala-ui/hooks/useSymbolzeit.ts:10

###
Settings

#### Member Visibility

- Protected
- Private
- Inherited
- External

#### Theme